@@ -392,7 +392,7 @@ from ae.core import DEBUG_LEVELS, registered_app_names
 from ae.console import ConsoleApp                                                                       # type: ignore
 
 
-__version__ = '0.1.69'
+__version__ = '0.1.70'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -434,6 +434,8 @@ HIDDEN_GLOBALS = (
 PORTIONS_IMAGES = FilesRegister()               #: register of image files found in portions/packages at import time
 PORTIONS_SOUNDS = FilesRegister()               #: register of sound files found in portions/packages at import time
 
+USER_NAME_MAX_LEN = 12          #: maximal length of a user name/id (restricting :attr:`~ae.console.ConsoleApp.user_id)
+
 
 check_all()     # let ae_updater module check/install any outstanding updates or new app versions
 
@@ -1181,11 +1183,11 @@ class MainAppBase(ConsoleApp, ABC):
         self.mix_background_ink()
 
     @staticmethod
-    def on_flow_popup_close(_flow_key: str, _popup_args: EventKwargsType) -> bool:
+    def on_flow_popup_close(_flow_key: str, _event_kwargs: EventKwargsType) -> bool:
         """ default popup close handler of FlowPopup widget, ensuring update of :attr:`flow_path`.
 
         :param _flow_key:       unused flow key.
-        :param _popup_args:     unused popup args.
+        :param _event_kwargs:   unused popup args.
         :return:                always returning True.
         """
         return True
